<?php
/*
Plugin Name: Smile Query
Plugin URI: https://smile-query.jp/
Description: スマイルクエリーは、LINEと連携する問い合わせフォームです。
Version: 1.0.0
Author: KnowledgeFlow
Author URI: https://smile-query.jp/
License: GPLv2 or later
License URI: http://www.gnu.org/licenses/gpl-2.0.html

Copyright 2018 KnowledgeFlow (email : info@smile-query.jp)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as
	published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

class SmileQueryForWordpress
{
    const PLUGIN_ID         = 'SmileQueryForWordpress';
    const CREDENTIAL_ACTION = self::PLUGIN_ID . '-nonce-action';
    const CREDENTIAL_NAME   = self::PLUGIN_ID . '-nonce-key';

    static $instance = false;
    
    // 最初に実行されます（クラスのインスタンス作成時）
    private function __construct() {
        add_action('admin_enqueue_scripts', array($this, 'add_css'));
        add_action('admin_menu', array($this, 'add_pages'));
        add_action('wp_footer', array($this, 'my_js_function'));
    }
    
    // クラスのインスタンスを返す。なかったら作成して返す。
    public static function getInstance() {
		if (!self::$instance)
			self::$instance = new self;
		return self::$instance;
    }
    
    // cssを追加
    public function add_css($hook){
        if ($hook == get_current_screen()->base) { // スマイルクエリーの画面だったら
            wp_register_style('sqry_style', plugins_url('css/sqry_style.css', __FILE__));
            wp_enqueue_style('sqry_style');
        }
    }

    // メニューバーに表示
    public function add_pages($hook){
        add_menu_page('スマイルクエリー', 'スマイルクエリー', 'level_8', __FILE__, array($this, 'show_main_form'), 'dashicons-admin-comments', 90);
    }

    // スクリプトを出力
    public function my_js_function() {
        $sqry_id = get_option( 'sqry_id', '' );
        if ($sqry_id == '') {
            return;
        }
        echo "
<script>
//script コード
(function () { var w = window, d = document;
var s = 'https://app.smile-query.jp/message/chat/bundle.js'; d.__sqry_id = '".$sqry_id."';
var a = d.createElement('script'), m = d.getElementsByTagName('script')[0];
a.async = true, a.src = s, m.parentNode.insertBefore(a, m); })();
</script>
        ";
    }

    // メインの画面
    public function show_main_form () { 
        if (
            isset($_POST['sqryid'])
            && isset($_POST[self::CREDENTIAL_NAME]) 
            && check_admin_referer(self::CREDENTIAL_ACTION, self::CREDENTIAL_NAME)
        ) {
            $form_sqry_id = strval($_POST['sqryid']);
            $form_sqry_id = sanitize_text_field($form_sqry_id);
            if (!$form_sqry_id) {
                $form_sqry_id = '';
            }

            if (strlen($form_sqry_id) > 200) {
                $form_sqry_id = substr($form_sqry_id, 0, 200);
            }
            
            update_option('sqry_id', $form_sqry_id);
            echo '<i><div id="message" class="updated notice is-dismissible"><p>プラグインキーを更新しました。</p>
            <button type="button" class="notice-dismiss"><span class="screen-reader-text">この通知を非表示にする</span></button></div></i>';
        }

        $sqry_id = get_option( 'sqry_id' );
?>

        <div class="wrap" style="background:#fff; padding:10px 20px;">		
            <h2><img src="<?=plugins_url('img/wp-logo.png', __FILE__)?>" alt="スマイルクエリー"></h2>
            <p>LINEと連携する問い合わせシステム「スマイルクエリー」を、お使いのWordPressサイトに設置します。<br>
        WordPressプラグインキーを入力してください。</p>
            <p>
                <form action="" method="post">
                    <?php wp_nonce_field(self::CREDENTIAL_ACTION, self::CREDENTIAL_NAME) ?>
                    <label>WordPressプラグインキー</label><input id="sqry-id" type="text" name="sqryid" value="<?=esc_html($sqry_id)?>"><button type="submit" class="button-primary" name="submit">更新</button>
                </form>
            </p>
        </div>
            <div class="flex">
                <div class="attentionBox">
                    <h3>スマイルクエリーって？</h3>
                      <p>スマイルクエリーは、LINEと連携する問い合わせフォームです。ご利用にはスマイルクエリーへの登録が必要です。<br>
                登録がお済みでない方は、こちらからご登録ください。</p>
                        <a href="http://smile-query.jp" target="_blank" onfocus="this.blur();"><div class="btn btn_regist">新規登録する</div></a>
                </div>
    
                <div class="attentionBox">
                    <h3>このプラグインの使い方は？</h3>
                      <p>スマイルクエリーの管理画面からIDを確認し、設定します。詳しくはサポートをご覧ください。</p>
                    <a href=" https://smile-query.jp/support_003_004/#003_002" target="_blank" onfocus="this.blur();"><div class="btn btn_help">サポートを見る</div></a>
                </div>
    
                <div class="attentionBox">
                    <h3>スマイルクエリーが表示されない！</h3>
                      <p><b style="color:#f00;">スマイルクエリーでのドメインの設定などが間違っていることがあります。</b>設定の確認方法について、詳しくはサポートをご覧ください。</p>
                    <a href=" https://smile-query.jp/support_003_004/#003_003" target="_blank" onfocus="this.blur();"><div class="btn btn_hiddenHelp">サポートを見る</div></a>
                </div>
            </div>

<?php
    
    }
}

// 実行
$SmileQueryForWordpress = SmileQueryForWordpress::getInstance();
?>